@@ -34,26 +34,27 @@
 
 #include <string.h>
 
+#include <gio/gio.h>
 #include <glib.h>
 #include <gtk/gtk.h>
-#include <gio/gio.h>
-
 #include <libxfce4util/libxfce4util.h>
-#include "xfdesktop-thumbnailer.h"
-#include "xfdesktop-marshal.h"
-#include "xfdesktop-common.h"
+
 #include "tumbler.h"
+#include "xfdesktop-common.h"
+#include "xfdesktop-marshal.h"
+#include "xfdesktop-thumbnailer.h"
 
-struct _XfdesktopThumbnailerPrivate
-{
-    TumblerThumbnailer1      *proxy;
+struct _XfdesktopThumbnailer {
+    GObject parent_instance;
 
-    GSList                   *queue;
-    gchar                   **supported_mimetypes;
-    gboolean                  big_thumbnails;
-    guint                     handle;
+    TumblerThumbnailer1 *proxy;
 
-    guint                     request_timer_id;
+    GSList *queue;
+    gchar **supported_mimetypes;
+    gboolean big_thumbnails;
+    guint handle;
+
+    guint request_timer_id;
 };
 
 static void xfdesktop_thumbnailer_dispose(GObject *object);
@@ -81,7 +82,7 @@ enum
 static guint thumbnailer_signals[LAST_SIGNAL] = { 0, };
 
 
-G_DEFINE_TYPE_WITH_PRIVATE(XfdesktopThumbnailer, xfdesktop_thumbnailer, G_TYPE_OBJECT);
+G_DEFINE_TYPE(XfdesktopThumbnailer, xfdesktop_thumbnailer, G_TYPE_OBJECT);
 
 
 static void
@@ -96,7 +97,7 @@ xfdesktop_thumbnailer_class_init(XfdesktopThumbnailerClass *klass)
                         "thumbnail-ready",
                         G_OBJECT_CLASS_TYPE (object_class),
                         G_SIGNAL_RUN_LAST,
-                        G_STRUCT_OFFSET(XfdesktopThumbnailerClass, thumbnail_ready),
+                        0,
                         NULL, NULL,
                         xfdesktop_marshal_VOID__STRING_STRING,
                         G_TYPE_NONE, 2,
@@ -108,40 +109,37 @@ xfdesktop_thumbnailer_init(XfdesktopThumbnailer *thumbnailer)
 {
     GDBusConnection *connection;
 
-    thumbnailer->priv = xfdesktop_thumbnailer_get_instance_private(thumbnailer);
-
     connection = g_bus_get_sync(G_BUS_TYPE_SESSION, NULL, NULL);
 
     if(connection) {
-        thumbnailer->priv->proxy = tumbler_thumbnailer1_proxy_new_sync(
-                                    connection,
-                                    G_DBUS_PROXY_FLAGS_NONE,
-                                    "org.freedesktop.thumbnails.Thumbnailer1",
-                                    "/org/freedesktop/thumbnails/Thumbnailer1",
-                                    NULL,
-                                    NULL);
+        thumbnailer->proxy = tumbler_thumbnailer1_proxy_new_sync(connection,
+                                                                 G_DBUS_PROXY_FLAGS_NONE,
+                                                                 "org.freedesktop.thumbnails.Thumbnailer1",
+                                                                 "/org/freedesktop/thumbnails/Thumbnailer1",
+                                                                 NULL,
+                                                                 NULL);
 
-        if(thumbnailer->priv->proxy) {
+        if(thumbnailer->proxy) {
             gchar **supported_uris = NULL;
             gchar **supported_flavors = NULL;
 
 
-            g_signal_connect(thumbnailer->priv->proxy,
+            g_signal_connect(thumbnailer->proxy,
                              "finished",
                              G_CALLBACK (xfdesktop_thumbnailer_request_finished_dbus),
                              thumbnailer);
-            g_signal_connect(thumbnailer->priv->proxy,
+            g_signal_connect(thumbnailer->proxy,
                              "ready",
                              G_CALLBACK(xfdesktop_thumbnailer_thumbnail_ready_dbus),
                              thumbnailer);
 
-            tumbler_thumbnailer1_call_get_supported_sync(thumbnailer->priv->proxy,
+            tumbler_thumbnailer1_call_get_supported_sync(thumbnailer->proxy,
                                                          &supported_uris,
-                                                         &thumbnailer->priv->supported_mimetypes,
+                                                         &thumbnailer->supported_mimetypes,
                                                          NULL,
                                                          NULL);
 
-            tumbler_thumbnailer1_call_get_flavors_sync(thumbnailer->priv->proxy,
+            tumbler_thumbnailer1_call_get_flavors_sync(thumbnailer->proxy,
                                                        &supported_flavors,
                                                        NULL,
                                                        NULL);
@@ -150,11 +148,11 @@ xfdesktop_thumbnailer_init(XfdesktopThumbnailer *thumbnailer)
                 gint n;
                 for(n = 0; supported_flavors[n] != NULL; ++n) {
                     if(g_strcmp0(supported_flavors[n], "large")) {
-                        thumbnailer->priv->big_thumbnails = TRUE;
+                        thumbnailer->big_thumbnails = TRUE;
                     }
                 }
             } else {
-                thumbnailer->priv->big_thumbnails = FALSE;
+                thumbnailer->big_thumbnails = FALSE;
                 g_warning("Thumbnailer failed calling GetFlavors");
             }
 
@@ -176,12 +174,12 @@ xfdesktop_thumbnailer_dispose(GObject *object)
 {
     XfdesktopThumbnailer *thumbnailer = XFDESKTOP_THUMBNAILER(object);
 
-    if (thumbnailer->priv->request_timer_id != 0) {
-        g_source_remove(thumbnailer->priv->request_timer_id);
-        thumbnailer->priv->request_timer_id = 0;
+    if (thumbnailer->request_timer_id != 0) {
+        g_source_remove(thumbnailer->request_timer_id);
+        thumbnailer->request_timer_id = 0;
     }
 
-    g_clear_object(&thumbnailer->priv->proxy);
+    g_clear_object(&thumbnailer->proxy);
 
     if (thumbnailer == thumbnailer_object) {
         thumbnailer_object = NULL;
@@ -200,10 +198,10 @@ xfdesktop_thumbnailer_finalize(GObject *object)
 {
     XfdesktopThumbnailer *thumbnailer = XFDESKTOP_THUMBNAILER(object);
 
-    g_slist_free(thumbnailer->priv->queue);
+    g_slist_free(thumbnailer->queue);
 
-    if (thumbnailer->priv->supported_mimetypes != NULL) {
-        g_strfreev(thumbnailer->priv->supported_mimetypes);
+    if (thumbnailer->supported_mimetypes != NULL) {
+        g_strfreev(thumbnailer->supported_mimetypes);
     }
 
     G_OBJECT_CLASS(xfdesktop_thumbnailer_parent_class)->finalize(object);
@@ -230,33 +228,31 @@ xfdesktop_thumbnailer_new(void)
 gboolean xfdesktop_thumbnailer_service_available(XfdesktopThumbnailer *thumbnailer)
 {
     g_return_val_if_fail(XFDESKTOP_IS_THUMBNAILER(thumbnailer), FALSE);
-
-    if(thumbnailer->priv->proxy == NULL)
-        return FALSE;
-
-    return TRUE;
+    return thumbnailer->proxy != NULL;
 }
 
 gboolean
 xfdesktop_thumbnailer_is_supported(XfdesktopThumbnailer *thumbnailer,
-                                   gchar *file)
+                                   gchar *filename)
 {
     guint        n;
     gchar       *mime_type = NULL;
 
     g_return_val_if_fail(XFDESKTOP_IS_THUMBNAILER(thumbnailer), FALSE);
-    g_return_val_if_fail(file != NULL, FALSE);
+    g_return_val_if_fail(filename != NULL, FALSE);
 
+    GFile *file = g_file_new_for_path(filename);
     mime_type = xfdesktop_get_file_mimetype(file);
+    g_object_unref(file);
 
     if(mime_type == NULL) {
-        XF_DEBUG("File %s has no mime type", file);
+        XF_DEBUG("File %s has no mime type", filename);
         return FALSE;
     }
 
-    if(thumbnailer->priv->supported_mimetypes != NULL) {
-        for(n = 0; thumbnailer->priv->supported_mimetypes[n] != NULL; ++n) {
-            if(g_content_type_is_a (mime_type, thumbnailer->priv->supported_mimetypes[n])) {
+    if (thumbnailer->supported_mimetypes != NULL) {
+        for(n = 0; thumbnailer->supported_mimetypes[n] != NULL; ++n) {
+            if(g_content_type_is_a (mime_type, thumbnailer->supported_mimetypes[n])) {
                 g_free(mime_type);
                 return TRUE;
             }
@@ -287,36 +283,34 @@ xfdesktop_thumbnailer_queue_thumbnail(XfdesktopThumbnailer *thumbnailer,
         XF_DEBUG("file: %s not supported", file);
         return FALSE;
     }
-    if(thumbnailer->priv->request_timer_id) {
-        g_source_remove(thumbnailer->priv->request_timer_id);
+    if (thumbnailer->request_timer_id != 0) {
+        g_source_remove(thumbnailer->request_timer_id);
 
-        if(thumbnailer->priv->handle && thumbnailer->priv->proxy != NULL) {
-            if(tumbler_thumbnailer1_call_dequeue_sync(thumbnailer->priv->proxy,
-                                                      thumbnailer->priv->handle,
-                                                      NULL,
-                                                      NULL) == FALSE)
+        if (thumbnailer->handle != 0 && thumbnailer->proxy != NULL) {
+            if (!tumbler_thumbnailer1_call_dequeue_sync(thumbnailer->proxy,
+                                                        thumbnailer->handle,
+                                                        NULL,
+                                                        NULL))
             {
                 /* If this fails it usually means there's a thumbnail already
                  * being processed, no big deal */
-                XF_DEBUG("Dequeue of thumbnailer->priv->handle: %d failed",
-                         thumbnailer->priv->handle);
+                XF_DEBUG("Dequeue of thumbnailer->handle: %d failed",
+                         thumbnailer->handle);
             }
 
-            thumbnailer->priv->handle = 0;
+            thumbnailer->handle = 0;
         }
     }
 
-    if(g_slist_find(thumbnailer->priv->queue, file) == NULL) {
-        thumbnailer->priv->queue = g_slist_prepend(thumbnailer->priv->queue,
-                                                   g_strdup(file));
+    if (g_slist_find(thumbnailer->queue, file) == NULL) {
+        thumbnailer->queue = g_slist_prepend(thumbnailer->queue, g_strdup(file));
     }
 
-    thumbnailer->priv->request_timer_id = g_timeout_add_full(
-                        G_PRIORITY_LOW,
-                        300,
-                        xfdesktop_thumbnailer_queue_request_timer,
-                        thumbnailer,
-                        NULL);
+    thumbnailer->request_timer_id = g_timeout_add_full(G_PRIORITY_LOW,
+                                                       300,
+                                                       xfdesktop_thumbnailer_queue_request_timer,
+                                                       thumbnailer,
+                                                       NULL);
 
     return TRUE;
 }
@@ -343,44 +337,43 @@ xfdesktop_thumbnailer_dequeue_thumbnail(XfdesktopThumbnailer *thumbnailer,
     g_return_if_fail(XFDESKTOP_IS_THUMBNAILER(thumbnailer));
     g_return_if_fail(file != NULL);
 
-    if(thumbnailer->priv->request_timer_id) {
-        g_source_remove(thumbnailer->priv->request_timer_id);
+    if (thumbnailer->request_timer_id != 0) {
+        g_source_remove(thumbnailer->request_timer_id);
 
-        if(thumbnailer->priv->handle && thumbnailer->priv->proxy) {
-            if(tumbler_thumbnailer1_call_dequeue_sync(thumbnailer->priv->proxy,
-                                                      thumbnailer->priv->handle,
-                                                      NULL,
-                                                      NULL) == FALSE)
+        if (thumbnailer->handle != 0 && thumbnailer->proxy != NULL) {
+            if (!tumbler_thumbnailer1_call_dequeue_sync(thumbnailer->proxy,
+                                                        thumbnailer->handle,
+                                                        NULL,
+                                                        NULL))
             {
                 /* If this fails it usually means there's a thumbnail already
                  * being processed, no big deal */
-                XF_DEBUG("Dequeue of thumbnailer->priv->handle: %d failed",
-                         thumbnailer->priv->handle);
+                XF_DEBUG("Dequeue of thumbnailer->handle: %d failed",
+                         thumbnailer->handle);
             }
         }
-        thumbnailer->priv->handle = 0;
+        thumbnailer->handle = 0;
     }
 
-    item = g_slist_find(thumbnailer->priv->queue, file);
+    item = g_slist_find(thumbnailer->queue, file);
     if(item != NULL) {
         g_free(item->data);
-        thumbnailer->priv->queue = g_slist_remove(thumbnailer->priv->queue,
+        thumbnailer->queue = g_slist_remove(thumbnailer->queue,
                                                   file);
     }
 
-    thumbnailer->priv->request_timer_id = g_timeout_add_full(
-                        G_PRIORITY_LOW,
-                        300,
-                        xfdesktop_thumbnailer_queue_request_timer,
-                        thumbnailer,
-                        NULL);
+    thumbnailer->request_timer_id = g_timeout_add_full(G_PRIORITY_LOW,
+                                                       300,
+                                                       xfdesktop_thumbnailer_queue_request_timer,
+                                                       thumbnailer,
+                                                       NULL);
 }
 
 void xfdesktop_thumbnailer_dequeue_all_thumbnails(XfdesktopThumbnailer *thumbnailer)
 {
     g_return_if_fail(XFDESKTOP_IS_THUMBNAILER(thumbnailer));
 
-    g_slist_foreach(thumbnailer->priv->queue, (GFunc)xfdesktop_thumbnailer_dequeue_foreach, thumbnailer);
+    g_slist_foreach(thumbnailer->queue, (GFunc)xfdesktop_thumbnailer_dequeue_foreach, thumbnailer);
 }
 
 static gboolean
@@ -397,17 +390,15 @@ xfdesktop_thumbnailer_queue_request_timer(gpointer user_data)
 
     g_return_val_if_fail(XFDESKTOP_IS_THUMBNAILER(thumbnailer), FALSE);
 
-    uris = g_new0(gchar *,
-                  g_slist_length(thumbnailer->priv->queue) + 1);
-    mimetypes = g_new0(gchar *,
-                       g_slist_length (thumbnailer->priv->queue) + 1);
+    uris = g_new0(gchar *, g_slist_length(thumbnailer->queue) + 1);
+    mimetypes = g_new0(gchar *, g_slist_length (thumbnailer->queue) + 1);
 
-    iter = thumbnailer->priv->queue;
+    iter = thumbnailer->queue;
     while(iter) {
         if(iter->data) {
             file = g_file_new_for_path(iter->data);
             uris[i] = g_file_get_uri(file);
-            mimetypes[i] = xfdesktop_get_file_mimetype(iter->data);
+            mimetypes[i] = xfdesktop_get_file_mimetype(file);
 
             g_object_unref(file);
         }
@@ -415,21 +406,22 @@ xfdesktop_thumbnailer_queue_request_timer(gpointer user_data)
         i++;
     }
 
-    if(thumbnailer->priv->big_thumbnails == TRUE)
+    if (thumbnailer->big_thumbnails) {
         thumbnail_flavor = "large";
-    else
+    } else {
         thumbnail_flavor = "normal";
+    }
 
-    if(thumbnailer->priv->proxy != NULL) {
-        if(tumbler_thumbnailer1_call_queue_sync(thumbnailer->priv->proxy,
-                                                (const gchar * const*)uris,
-                                                (const gchar * const*)mimetypes,
-                                                thumbnail_flavor,
-                                                "default",
-                                                0,
-                                                &thumbnailer->priv->handle,
-                                                NULL,
-                                                &error) == FALSE)
+    if (thumbnailer->proxy != NULL) {
+        if (!tumbler_thumbnailer1_call_queue_sync(thumbnailer->proxy,
+                                                  (const gchar * const*)uris,
+                                                  (const gchar * const*)mimetypes,
+                                                  thumbnail_flavor,
+                                                  "default",
+                                                  0,
+                                                  &thumbnailer->handle,
+                                                  NULL,
+                                                  &error))
         {
             if(error != NULL)
                 g_warning("DBUS-call failed: %s", error->message);
@@ -438,7 +430,7 @@ xfdesktop_thumbnailer_queue_request_timer(gpointer user_data)
 
     /* Free the memory */
     i = 0;
-    iter = thumbnailer->priv->queue;
+    iter = thumbnailer->queue;
     while(iter) {
         if(iter->data) {
             g_free(uris[i]);
@@ -452,7 +444,7 @@ xfdesktop_thumbnailer_queue_request_timer(gpointer user_data)
     g_free(mimetypes);
     g_clear_error(&error);
 
-    thumbnailer->priv->request_timer_id = 0;
+    thumbnailer->request_timer_id = 0;
 
     return FALSE;
 }
@@ -466,7 +458,7 @@ xfdesktop_thumbnailer_request_finished_dbus(TumblerThumbnailer1 *proxy,
 
     g_return_if_fail(XFDESKTOP_IS_THUMBNAILER(thumbnailer));
 
-    thumbnailer->priv->handle = 0;
+    thumbnailer->handle = 0;
 }
 
 static void
@@ -478,7 +470,7 @@ xfdesktop_thumbnailer_thumbnail_ready_dbus(TumblerThumbnailer1 *proxy,
     XfdesktopThumbnailer *thumbnailer = XFDESKTOP_THUMBNAILER(data);
     gchar *thumbnail_location;
     GFile *file;
-    GSList *iter = thumbnailer->priv->queue;
+    GSList *iter = thumbnailer->queue;
     gchar *f_uri, *f_uri_checksum, *filename, *temp;
     gchar *thumbnail_flavor;
     gint x = 0;
@@ -504,10 +496,11 @@ xfdesktop_thumbnailer_thumbnail_ready_dbus(TumblerThumbnailer1 *proxy,
             f_uri_checksum = g_compute_checksum_for_string(G_CHECKSUM_MD5,
                                                            f_uri, strlen (f_uri));
 
-            if(thumbnailer->priv->big_thumbnails == TRUE)
+            if (thumbnailer->big_thumbnails) {
                 thumbnail_flavor = "large";
-            else
+            } else {
                 thumbnail_flavor = "normal";
+            }
 
             filename = g_strconcat(f_uri_checksum, ".png", NULL);
 
@@ -538,10 +531,9 @@ xfdesktop_thumbnailer_thumbnail_ready_dbus(TumblerThumbnailer1 *proxy,
             }
 
             temp = iter->data;
-            thumbnailer->priv->queue = g_slist_remove(thumbnailer->priv->queue,
-                                                      temp);
+            thumbnailer->queue = g_slist_remove(thumbnailer->queue, temp);
 
-            iter = thumbnailer->priv->queue;
+            iter = thumbnailer->queue;
             x++;
 
             g_free(filename);
